@@ -7,8 +7,14 @@
 #' @param terms Terms/markers of the rows that are to be removed from the 
 #' dataframe.  The term/marker must appear at the beginning of the string and is 
 #' case sensitive.
+#' @param contains logical.  If \code{TRUE} \code{rm_row} searches for the terms 
+#' anywhere within the string.  If \code{FALSE} \code{rm_row} searches only the 
+#' beginning of the string.
+#' @param ignore.case logical.  If \code{TRUE} case is ignored during matching, 
+#' if \code{FALSE}the pattern matching is case sensitive.
 #' @param keep.rownames logical.  If \code{TRUE} the original, non-sequential, 
 #' rownames will be used. 
+#' @param \ldots Other arguments passed to \code{\link[base]{grepl}}.
 #' @return \code{rm_row} - returns a dataframe with the termed/markered rows 
 #' removed.
 #' @rdname rm_row
@@ -19,27 +25,42 @@
 #' rm_row(DATA, "person", c("sam", "greg"))
 #' rm_row(DATA, 1, c("sam", "greg"))
 #' rm_row(DATA, "state", c("Comp"))
+#' rm_row(DATA, "state", c("I "))
+#' rm_row(DATA, "state", c("you"), contains = TRUE, ignore.case=TRUE)
 #' 
 #' #rm_empty_row EXAMPLE:
 #' (dat <- rbind.data.frame(DATA[, c(1, 4)], matrix(rep(" ", 4), 
 #'    ncol =2, dimnames=list(12:13, colnames(DATA)[c(1, 4)]))))
 #' rm_empty_row(dat)
 #' }
-rm_row <-
-function(dataframe, search.column, terms, keep.rownames = FALSE) {
-    FUN <- function(dat, sc, term) {
-        dat[substring(dat[, sc], 1, nchar(term)) != term, ]
-        
-    }
-    DF <- dataframe
-    lapply(terms, function(x) {
-            DF <<- FUN(DF, search.column, x)
+rm_row <- 
+function (dataframe, search.column, terms, contains = FALSE, ignore.case = FALSE,
+    keep.rownames = FALSE, ...) {
+
+    if (contains) {
+        FUN <- function(dat, sc, term) {
+            dat[!grepl(term, dat[, sc], ignore.case = ignore.case, ...),]
+        }
+    } else {
+        if (!ignore.case) {
+            FUN <- function(dat, sc, term) {
+                dat[substring(dat[, sc], 1, nchar(term)) != term, ]
+            }
+        } else {
+            FUN <- function(dat, sc, term) {
+                dat[tolower(substring(dat[, sc], 1, nchar(term))) != tolower(term), ]
+            }
         }
-    )
-    if (!keep.rownames) {
-        DF <- data.frame(DF, row.names = NULL, stringsAsFactors = FALSE)
     }
-    return(DF)
+
+    lapply(terms, function(x) {
+        dataframe <<- FUN(dataframe, search.column, x)
+    })
+
+    if (!keep.rownames) {
+        rownames(dataframe) <- NULL
+    }
+    dataframe
 }
 
 
