@@ -1,4 +1,4 @@
-#' tm Package Compatability Tools: Apply to or Convert to/from Term Document 
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
 #' \code{tdm} - Create term document matrices from raw text or 
@@ -11,7 +11,8 @@
 #' @param \ldots If \code{tdm} or \code{dtm} - Other arguments passed to 
 #' \code{wfm}.  If \code{apply_as_tm} - Other arguments passed to functions used 
 #' on the tm package's \code{"TermDocumentMatrix"}.  If \code{df2tm_corpus} - 
-#' Other arguments passed to the tm package's \code{\link[tm]{Corpus}}.
+#' Other arguments passed to the tm package's \code{\link[tm]{Corpus}}.  If 
+#' \code{tm_corpus2wfm} - Other arguments passed to \code{\link[qdap]{wfm}}.
 #' @param vowel.check logical.  Should terms without vowels be remove?  
 #' @details Produces output that is identical to the \code{tm} package's 
 #' \code{\link[tm]{TermDocumentMatrix}}, \code{\link[tm]{DocumentTermMatrix}},
@@ -238,6 +239,40 @@
 #' class(x)
 #' 
 #' (y <- with(pres_debates2012, df2tm_corpus(dialogue, list(person, time))))
+#' 
+#' ## Apply qdap functions meant for dataframes from sentSplit to tm Corpus
+#' library(tm)
+#' reut21578 <- system.file("texts", "crude", package = "tm")
+#' reuters <- Corpus(DirSource(reut21578),
+#'     readerControl = list(reader = readReut21578XML))
+#' 
+#' apply_as_df(reuters, word_stats)
+#' apply_as_df(reuters, formality)
+#' apply_as_df(reuters, word_list)
+#' apply_as_df(reuters, polarity)
+#' apply_as_df(reuters, Dissimilarity)
+#' apply_as_df(reuters, diversity)
+#' apply_as_df(reuters, pos_by)
+#' apply_as_df(reuters, flesch_kincaid)
+#' apply_as_df(reuters, trans_venn)
+#' apply_as_df(reuters, gantt_plot)
+#' apply_as_df(reuters, rank_freq_mplot)
+#' apply_as_df(reuters, termco, 
+#'     match.list = list(
+#'         oil = qcv(oil, Texas, crude), 
+#'         money = c("economic", "money")
+#'     ))
+#' plot(apply_as_df(reuters, termco, 
+#'     match.list = list(
+#'         oil = qcv(oil, Texas, crude), 
+#'         money = c("economic", "money")
+#'     ), elim.old = FALSE), values = TRUE, high="red")
+#' apply_as_df(reuters, word_cor, 
+#'     word = qcv(oil, Texas, crude, economic, money)
+#' )
+#' plot(apply_as_df(reuters, word_cor, 
+#'     word = qcv(oil, Texas, crude, economic, money)
+#' ))
 #' }
 tdm <- function(text.var, grouping.var = NULL, vowel.check = TRUE, ...) {
 
@@ -276,7 +311,7 @@ vowel_check <- function(text.var) {
 
 
 
-#' tm Package Compatability Tools: Apply to or Convert to/from Term Document 
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
 #' \code{dtm} - Create document term matrices from raw text or 
@@ -329,7 +364,7 @@ wfm2xtab <- function(text.var, grouping.var = NULL, ...) {
 }
 
 
-#' tm Package Compatability Tools: Apply to or Convert to/from Term Document 
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
 #' \code{tm2qdap} - Convert the \code{tm} package's 
@@ -338,7 +373,7 @@ wfm2xtab <- function(text.var, grouping.var = NULL, ...) {
 #' 
 #' @param x A \code{\link[tm]{TermDocumentMatrix}}/\code{\link[tm]{DocumentTermMatrix}}.
 #' @return \code{tm2qdap} - Returns a \code{\link[qdap]{wfm}} object or 
-#' \code{\link[qdap]{wfm_weight}} object.
+#' \code{weight} object.
 #' @rdname tdm
 #' @export
 tm2qdap <- function(x) {
@@ -363,7 +398,7 @@ tm2qdap <- function(x) {
 }
 
 
-#' tm Package Compatability Tools: Apply to or Convert to/from Term Document 
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
 #' \code{apply_as_tm} - Apply functions intended to be used on the \code{tm} 
@@ -377,7 +412,7 @@ tm2qdap <- function(x) {
 #' coerce the output back to a qdap object.
 #' @return \code{apply_as_tm} - Applies a tm oriented function to a 
 #' \code{\link[qdap]{wfm}} and attempts to simplify back to a 
-#' \code{\link[qdap]{wfm}} or \code{\link[qdap]{wfm_weight}} format.
+#' \code{\link[qdap]{wfm}} or \code{weight} format.
 #' @rdname tdm
 #' @export
 apply_as_tm <- function(wfm.obj, tmfun, ..., to.qdap = TRUE){
@@ -397,7 +432,7 @@ apply_as_tm <- function(wfm.obj, tmfun, ..., to.qdap = TRUE){
 
 }
 
-#' tm Package Compatability Tools: Apply to or Convert to/from Term Document 
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
 #' \code{tm_corpus2df} - Convert a tm package corpus to a dataframe.
@@ -418,7 +453,25 @@ tm_corpus2df <- function(tm.corpus, col1 = "docs", col2 = "text") {
     list2df(tm.corpus, col1 = col2, col2 = col1)[, 2:1]
 }
 
-#' tm Package Compatability Tools: Apply to or Convert to/from Term Document 
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
+#' Matrix or Document Term Matrix
+#' 
+#' \code{tm_corpus2wfm} - Convert a \code{\link[tm]{Corpus}} package corpus to a 
+#' \code{\link[qdap]{wfm}}. 
+#' 
+#' @rdname tdm
+#' @return \code{df2tm_wfm} - Converts a qdap oriented dataframe and returns 
+#' a \code{\link[qdap]{wfm}}.
+#' @export
+tm_corpus2wfm <- function(tm.corpus, col1 = "docs", col2 = "text", ...) {
+
+      text <- docs <- NULL
+      with(tm_corpus2df(tm.corpus), wfm(text, docs, ...))  
+
+}
+
+
+#' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
 #' \code{df2tm_corpus} - Convert a qdap dataframe to a tm package 
@@ -461,12 +514,108 @@ df2tm_corpus <- function(text.var, grouping.var = NULL, ...){
     DF[, "grouping"] <- factor(DF[, "grouping"])
     DF[, "text.var"] <- as.character(DF[, "text.var"])
 
-    ## Split apart by grouping variables and collpase text
+    ## Split apart by grouping variables and collapse text
     LST <- sapply(split(DF[, "text.var"], DF[, "grouping"]), 
         paste, collapse = " ")
 
     ## Use the tm package to convert to a Corpus
-    Corpus(VectorSource(LST), ...)
+    mycorpus <- Corpus(VectorSource(LST), ...)
+    
+    ## Add metadata info
+    attributes(mycorpus)[["DMetaData"]][,1] <- names(LST)
+    pers <- unname(Sys.info()["user"])
+    if (!is.null(pers)) {
+        attributes(mycorpus)[["CMetaData"]][["MetaData"]][["creator"]] <- pers
+    }
+    mycorpus
+}
+
+#' Transposes a TermDocumentMatrix object
+#' 
+#' Transposes a TermDocumentMatrix object
+#' 
+#' @param x The TermDocumentMatrix object
+#' @param \ldots ignored
+#' @S3method t TermDocumentMatrix
+#' @method t TermDocumentMatrix
+t.TermDocumentMatrix <- function(x, ...) {
+     
+    x <- t(as.matrix(x))
+
+    z <- unlist(apply(x, 2, function(y) sum(y != 0)), use.names = FALSE)
+
+    a <- list(
+        unlist(apply(x, 2, function(y) which(y != 0)), use.names = FALSE),
+        rep(seq_along(z), z),
+        x[apply(x, 2, function(y) y != 0)],
+        nrow(x),
+        ncol(x),
+        dimnames(x)
+    )
+    
+    attributes(a) <- list(
+            class = c("DocumentTermMatrix", "simple_triplet_matrix"),
+            Weighting = c("term frequency", "tf")
+    )
+    
+    names(a) <- c("i", "j", "v", "nrow", "ncol", "dimnames")
+    a
+}
+
+#' Transposes a DocumentTermMatrix object
+#' 
+#' Transposes a DocumentTermMatrix object
+#' 
+#' @param x The DocumentTermMatrix object
+#' @param \ldots ignored
+#' @S3method t DocumentTermMatrix
+#' @method t DocumentTermMatrix
+t.DocumentTermMatrix <- function(x, ...) {
+     
+    x <- t(as.matrix(x))
+
+    z <- unlist(apply(x, 2, function(y) sum(y != 0)), use.names = FALSE)
+
+    a <- list(
+        unlist(apply(x, 2, function(y) which(y != 0)), use.names = FALSE),
+        rep(seq_along(z), z),
+        x[apply(x, 2, function(y) y != 0)],
+        nrow(x),
+        ncol(x),
+        dimnames(x)
+    )
+    
+
+    attributes(a) <- list(
+            class = c("TermDocumentMatrix", "simple_triplet_matrix"),
+            Weighting = c("term frequency", "tf")
+    )
+    
+    names(a) <- c("i", "j", "v", "nrow", "ncol", "dimnames")
+    a
+}
+
+#' Apply a tm Corpus as a qdap Dataframe
+#' 
+#' Apply a \pkg{tm} \code{\link[tm]{Corpus}} as a qdap dataframe.
+#' 
+#' @param qdapfun A qdap function that is usually used on 
+#' text.variable ~ grouping variable.
+#' @note \code{aply_ad_df} coerces to a dataframe with columns named `docs` and 
+#' the other named `docs`.
+#' @export
+#' @rdname tdm
+apply_as_df <- function(tm.corpus, qdapfun, ...) {
+
+    text <- doc <- tot <- NULL
+
+    dat <- sentSplit(tm_corpus2df(tm.corpus), "text")
+    if (any(unlist(formals(qdapfun)) %in% "tot")) {
+        with(dat, qdapfun(text.var = text, grouping.var = docs, tot = tot,  ...))
+    } else {
+        with(dat, qdapfun(text.var = text, grouping.var = docs, ...))
+    }
 
 }
 
+
